from setuptools import setup

setup(author='Nelson Liu, Aakash Sethi',
      author_email='nfliu@uw.edu, aakash.k.sethi@gmail.com',
      description='Convert descriptions of colors to colors',
      install_requires=[
          'appnope==0.1.0',
          'beautifulsoup4==4.4.1',
          'cv2==2.4.12',
          'cycler==0.10.0',
          'decorator==4.0.9',
          'gnureadline==6.3.3',
          'ipython==4.1.2',
          'ipython-genutils==0.1.0',
          'numpy==1.11.0',
          'pathlib2==2.1.0',
          'pexpect==4.0.1',
          'pickleshare==0.7.2',
          'ptyprocess==0.5.1',
          'pyparsing==2.1.1',
          'python-dateutil==2.5.2',
          'pytz==2016.3',
          'requests==2.9.1',
          'scikit-learn==0.17.1',
          'scipy==0.17.0',
          'simplegeneric==0.8.1',
          'six==1.10.0',
          'traitlets==4.2.1',
          'webcolors==1.5'
          ],
      license='MIT',
      long_description='A tool for transforming natural language descriptions of colors to web-standard color names',
      name='word2color',
      packages=['word2color'],
      url='https://github.com/nelson-liu/word2color',
      version='0.1.1',
      zip_safe=False
)



import os
import shutil
import webcolors

from average_colors import color_kmeans
from scrape_bing import scrape_bing

def closest_colour(requested_colour):
    min_colours = {}
    for key, name in webcolors.html4_hex_to_names.items():
        r_c, g_c, b_c = webcolors.hex_to_rgb(key)
        rd = (r_c - requested_colour[0]) ** 2
        gd = (g_c - requested_colour[1]) ** 2
        bd = (b_c - requested_colour[2]) ** 2
        min_colours[(rd + gd + bd)] = name
    return min_colours[min(min_colours.keys())]

def get_colour_name(requested_colour):
    try:
        closest_name = actual_name = webcolors.rgb_to_name(requested_colour)
    except ValueError:
        closest_name = closest_colour(requested_colour)
        actual_name = None
    return actual_name, closest_name


def color_description_to_bin(color):
    # Fetch images and store in images/<color>
    scraper = scrape_bing.BingScraper()
    scraper.download_images(color, 3)

    # Get list of resulting images
    images = map(lambda x: 'images/' + color + '/' + x, os.listdir('images/' + color))

    average_color = color_kmeans.get_average_colors(images)

    actual_name, closest_name = get_colour_name(tuple(average_color))

    shutil.rmtree('./images')
    return closest_name
